emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r108870: * fileio.c (time_error_value


From: Paul Eggert
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r108870: * fileio.c (time_error_value): Rename from special_mtime.
Date: Wed, 04 Jul 2012 10:11:11 -0700
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 108870
committer: Paul Eggert <address@hidden>
branch nick: trunk
timestamp: Wed 2012-07-04 10:11:11 -0700
message:
  * fileio.c (time_error_value): Rename from special_mtime.
  
  The old name's problems were noted by Eli Zaretskii in
  <http://lists.gnu.org/archive/html/emacs-devel/2012-07/msg00087.html>.
modified:
  src/ChangeLog
  src/fileio.c
=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2012-07-04 17:04:09 +0000
+++ b/src/ChangeLog     2012-07-04 17:11:11 +0000
@@ -1,5 +1,9 @@
 2012-07-04  Paul Eggert  <address@hidden>
 
+       * fileio.c (time_error_value): Rename from special_mtime.
+       The old name's problems were noted by Eli Zaretskii in
+       <http://lists.gnu.org/archive/html/emacs-devel/2012-07/msg00087.html>.
+
        * emacs.c (gdb_pvec_type): Change it back to enum pvec_type.
        This variable's comment says Emacs needs at least one GDB-visible
        symbol of type enum pvec_type, to work around GDB problems.

=== modified file 'src/fileio.c'
--- a/src/fileio.c      2012-07-04 00:04:46 +0000
+++ b/src/fileio.c      2012-07-04 17:11:11 +0000
@@ -3213,9 +3213,9 @@
   return lseek (fd, offset, whence);
 }
 
 /* Return a special mtime value indicating the error number ERRNUM.  */
 static EMACS_TIME
-special_mtime (int errnum)
+time_error_value (int errnum)
 {
   EMACS_TIME t;
   int ns = (errno == ENOENT || errno == EACCES || errno == ENOTDIR
@@ -3336,7 +3336,7 @@
       save_errno = errno;
       if (NILP (visit))
        report_file_error ("Opening input file", Fcons (orig_filename, Qnil));
-      mtime = special_mtime (save_errno);
+      mtime = time_error_value (save_errno);
       st.st_size = -1;
       how_much = 0;
       if (!NILP (Vcoding_system_for_read))
@@ -5106,7 +5106,7 @@
 
   mtime = (stat (SSDATA (filename), &st) == 0
           ? get_stat_mtime (&st)
-          : special_mtime (errno));
+          : time_error_value (errno));
   if ((EMACS_TIME_EQ (mtime, b->modtime)
        /* If both exist, accept them if they are off by one second.  */
        || (EMACS_TIME_VALID_P (mtime) && EMACS_TIME_VALID_P (b->modtime)
@@ -3213,9 +3213,9 @@
 }
 
-/* Return a special mtime value indicating the error number ERRNUM.  */
+/* Return a special time value indicating the error number ERRNUM.  */
 static EMACS_TIME


reply via email to

[Prev in Thread] Current Thread [Next in Thread]